package com.winhc.max.compute.graph.job;


import com.aliyun.odps.data.TableInfo;
import com.aliyun.odps.graph.GraphJob;
import com.aliyun.odps.graph.RemoveDuplicatesLoadingResolver;
import com.winhc.max.compute.graph.job.pagerank.CompanyComputingVertexResolver;
import com.winhc.max.compute.graph.job.pagerank.CompanyRankVertex;
import com.winhc.max.compute.graph.job.pagerank.CompanyRankVertexReader;
import com.winhc.max.compute.graph.job.pagerank.PageRankAggregator;
import com.winhc.max.compute.graph.util.ParameterTool;
import org.apache.log4j.Logger;

import java.io.IOException;

/**
 * @author: XuJiakai
 * 2022/5/27 14:59
 */
public class CompanyRankGraphJob {
    private final static Logger log = Logger.getLogger(CompanyRankGraphJob.class);

    public static void main(String[] args) throws IOException {
        ParameterTool parameterTool = ParameterTool.fromArgs(args);
        String outPart = parameterTool.getOrDefault("outPart", "" + System.currentTimeMillis());
        String maxIter = parameterTool.getOrDefault("maxIter", "30");
        String variance = parameterTool.getOrDefault("variance", "0.00000001");

        System.out.println("input args: " + String.join(" ", args));

        GraphJob job = new GraphJob();

        job.set("company.rank.variance", variance);

        job.setGraphLoaderClass(CompanyRankVertexReader.class);
        job.setVertexClass(CompanyRankVertex.class);


        job.setLoadingVertexResolver(RemoveDuplicatesLoadingResolver.class);
        job.setComputingVertexResolver(CompanyComputingVertexResolver.class);
        job.setAggregatorClass(PageRankAggregator.class);


        job.addInput(TableInfo.builder()
                .projectName("winhc_ng")
                .tableName("calc_company_rank_input")
                .build());
        job.addOutput(TableInfo.builder()
                .projectName("winhc_ng")
                .tableName("calc_company_rank_out")
                .partSpec("ds='" + outPart + "'")
                .build());
        job.setMaxIteration(-1);

        long startTime = System.currentTimeMillis();
        job.run();
        System.out.println("Job Finished in "
                + (System.currentTimeMillis() - startTime) / 1000.0 + " seconds");
    }
}
